@@ -17,7 +17,7 @@
 * @author     Florian Anderiasch <fa@php.net>
 * @copyright  1997-2005 The PHP Group
 * @license    http://www.php.net/license/3_01.txt  PHP License 3.01
-* @version    CVS: $Id: IPv4.php 302879 2010-08-30 06:52:41Z bate $
+* @version    CVS: $Id$
 * @link       http://pear.php.net/package/Net_IPv4
 */
 
@@ -32,41 +32,7 @@ require_once 'PEAR.php';
  *
  * @global array $GLOBALS['Net_IPv4_Netmask_Map']
  */
-$GLOBALS['Net_IPv4_Netmask_Map'] = array(
-            0 => "0.0.0.0",
-            1 => "128.0.0.0",
-            2 => "192.0.0.0",
-            3 => "224.0.0.0",
-            4 => "240.0.0.0",
-            5 => "248.0.0.0",
-            6 => "252.0.0.0",
-            7 => "254.0.0.0",
-            8 => "255.0.0.0",
-            9 => "255.128.0.0",
-            10 => "255.192.0.0",
-            11 => "255.224.0.0",
-            12 => "255.240.0.0",
-            13 => "255.248.0.0",
-            14 => "255.252.0.0",
-            15 => "255.254.0.0",
-            16 => "255.255.0.0",
-            17 => "255.255.128.0",
-            18 => "255.255.192.0",
-            19 => "255.255.224.0",
-            20 => "255.255.240.0",
-            21 => "255.255.248.0",
-            22 => "255.255.252.0",
-            23 => "255.255.254.0",
-            24 => "255.255.255.0",
-            25 => "255.255.255.128",
-            26 => "255.255.255.192",
-            27 => "255.255.255.224",
-            28 => "255.255.255.240",
-            29 => "255.255.255.248",
-            30 => "255.255.255.252",
-            31 => "255.255.255.254",
-            32 => "255.255.255.255"
-        );
+$GLOBALS['Net_IPv4_Netmask_Map'] = Net_IPv4::$Net_IPv4_Netmask_Map;
 // }}}
 // {{{ Net_IPv4
 
@@ -96,6 +62,41 @@ class Net_IPv4
     var $network = "";
     var $broadcast = "";
     var $long = 0;
+    public static $Net_IPv4_Netmask_Map = array(
+        0 => "0.0.0.0",
+        1 => "128.0.0.0",
+        2 => "192.0.0.0",
+        3 => "224.0.0.0",
+        4 => "240.0.0.0",
+        5 => "248.0.0.0",
+        6 => "252.0.0.0",
+        7 => "254.0.0.0",
+        8 => "255.0.0.0",
+        9 => "255.128.0.0",
+        10 => "255.192.0.0",
+        11 => "255.224.0.0",
+        12 => "255.240.0.0",
+        13 => "255.248.0.0",
+        14 => "255.252.0.0",
+        15 => "255.254.0.0",
+        16 => "255.255.0.0",
+        17 => "255.255.128.0",
+        18 => "255.255.192.0",
+        19 => "255.255.224.0",
+        20 => "255.255.240.0",
+        21 => "255.255.248.0",
+        22 => "255.255.252.0",
+        23 => "255.255.254.0",
+        24 => "255.255.255.0",
+        25 => "255.255.255.128",
+        26 => "255.255.255.192",
+        27 => "255.255.255.224",
+        28 => "255.255.255.240",
+        29 => "255.255.255.248",
+        30 => "255.255.255.252",
+        31 => "255.255.255.254",
+        32 => "255.255.255.255"
+    );
 
     // }}}
     // {{{ validateIP()
@@ -154,7 +155,7 @@ class Net_IPv4
      */
     function validateNetmask($netmask)
     {
-        if (! in_array($netmask, $GLOBALS['Net_IPv4_Netmask_Map'])) {
+        if (! in_array($netmask, self::$Net_IPv4_Netmask_Map)) {
             return false;
         }
         return true;
@@ -264,7 +265,7 @@ class Net_IPv4
      */
     function calculate()
     {
-        $validNM = $GLOBALS['Net_IPv4_Netmask_Map'];
+        $validNM = self::$Net_IPv4_Netmask_Map;
 
         if (! is_a($this, "net_ipv4")) {
             $myself = new Net_IPv4;
